@@ -4,6 +4,7 @@ from os.path import exists
 from subprocess import PIPE, Popen
 from typing import List
 
+import sila2
 from sila2.code_generator.template_environment import TemplateEnvironment
 
 
@@ -21,6 +22,8 @@ class CodeGeneratorBase:
         if exists(out_filename) and open(out_filename).read() != content and not (self.overwrite or allow_overwrite):
             raise FileExistsError(f"File '{out_filename}' already exists. Set --overwrite to overwrite existing files.")
         with open(out_filename, "w") as fp:
+            if out_filename.endswith(".py"):
+                fp.write(f"# Generating by sila2.code_generator; sila2.__version__: {sila2.__version__}\n")
             fp.write(content)
 
         self.generated_files.append(out_filename)
