@@ -6,7 +6,6 @@ from glob import glob
 from os.path import dirname, isdir, join
 from typing import List, Optional
 
-import sila2.code_generator
 from sila2.code_generator.code_generator import CodeGenerator
 from sila2.code_generator.feature_generator import FeatureGenerator
 from sila2.framework import Feature
@@ -123,7 +122,6 @@ def find_matching_directory(pattern: str) -> str:
 
 def main(argv: Optional[List[str]] = None) -> int:
     parser = ArgumentParser(
-        prog=sila2.code_generator.__name__,
         description="SiLA 2 Python Code Generator",
     )
     parser.add_argument("--debug", action="store_true", help="Display more detailed error messages")
@@ -146,15 +144,19 @@ def main(argv: Optional[List[str]] = None) -> int:
         help="Add default implementations of the core features "
         "AuthenticationService, AuthorizationProviderService and AuthorizationService",
     )
-    package_parser.add_argument("feature_definitions", nargs="*", help="SiLA 2 feature definitions")
+    package_parser.add_argument("feature_definitions", nargs="*", help="SiLA 2 feature definition files (*.sila.xml)")
     package_parser.set_defaults(func=package)
 
     # feature addition subparser
     add_features_parser = commands.add_parser(
         "add-features", description="Add features to previously generated package"
     )
-    add_features_parser.add_argument("-d", "--package-dir", default=".", help="Package directory (contains 'setup.py')")
-    add_features_parser.add_argument("feature_definitions", nargs="*", help="SiLA 2 feature definitions")
+    add_features_parser.add_argument(
+        "-d", "--package-dir", default=".", help="Package directory (default: current directory)"
+    )
+    add_features_parser.add_argument(
+        "feature_definitions", nargs="*", help="SiLA 2 feature definition files (*.sila.xml)"
+    )
     add_features_parser.set_defaults(func=add_features)
 
     # package update subparser
@@ -163,7 +165,9 @@ def main(argv: Optional[List[str]] = None) -> int:
         description="Update a previously generated package after modifications to the feature definitions "
         "(refreshes the 'generated' submodule)",
     )
-    update_parser.add_argument("-d", "--package-dir", default=".", help="Package directory (contains 'setup.py')")
+    update_parser.add_argument(
+        "-d", "--package-dir", default=".", help="Package directory (default: current directory)"
+    )
     update_parser.set_defaults(func=update)
 
     args = parser.parse_args(argv)
