@@ -6,7 +6,9 @@ from sila2.framework.command.observable_command import ObservableCommand
 from sila2.framework.command.parameter import Parameter
 from sila2.framework.command.response import Response
 from sila2.framework.command.unobservable_command import UnobservableCommand
+from sila2.framework.data_types.any import SilaAnyType
 from sila2.framework.data_types.data_type_definition import DataTypeDefinition
+from sila2.framework.data_types.date import SilaDateType
 from sila2.framework.defined_execution_error_node import DefinedExecutionErrorNode
 from sila2.framework.errors.command_execution_not_accepted import CommandExecutionNotAccepted
 from sila2.framework.errors.command_execution_not_finished import CommandExecutionNotFinished
@@ -39,7 +41,9 @@ __all__ = [
     "NoMetadataAllowed",
     "ObservableCommand",
     "ObservableProperty",
+    "SilaAnyType",
     "SilaConnectionError",
+    "SilaDateType",
     "SilaError",
     "UndefinedExecutionError",
     "UnobservableProperty",
