@@ -11,7 +11,7 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
-class FullyQualifiedIdentifier(Constraint):
+class FullyQualifiedIdentifier(Constraint[str]):
     id_type: str
 
     def __init__(self, id_type: str):
